# sluyspy #

![PyPI](https://img.shields.io/pypi/v/sluyspy?color=%230A0) ![PyPI -
Downloads](https://img.shields.io/pypi/dm/sluyspy) [![Documentation
Status](https://readthedocs.org/projects/sluyspy/badge/?version=latest)](https://sluyspy.readthedocs.io/en/latest/?badge=latest)
![PyPI - License](https://img.shields.io/pypi/l/sluyspy?color=%230A0)

Marc van der Sluys' personal Python modules: functions that I should have found elsewhere but didn't.  The
code is being developed by [Marc van der Sluys](http://marc.vandersluys.nl) of the Institute of Nuclear and
High-Energy Physics (Nikhef) in Amsterdam and the Department of Physics at Utrecht University, both in The
Netherlands.  The sluyspy package can be used under the conditions of the [EUPL
1.2](https://www.eupl.eu/1.2/en/) licence.  Note that a lot of trial and error is going on, and there is no
guarantee of backward compatibility.  You may want to borrow a function rather than use the package.


## Installation ##

This package can be installed using `pip install sluyspy`.  This should automatically install the
dependency packages `numpy`, `pandas` and `matplotlib`, if they haven't been installed already.  If you are
installing by hand, ensure that these packages are installed as well.


## Example use ##

```python
"""Example Python script using the sluyspy package."""

import sluyspy

```

## sluyspy pages ##

* [Pypi](https://pypi.org/project/sluyspy/): sluyspy Python package
* [GitHub](https://github.com/MarcvdSluys/sluyspy/): sluyspy source code
* [ReadTheDocs](https://sluyspy.readthedocs.io/): sluyspy documentation


## Author and licence ##

* Author: Marc van der Sluys
* Contact: http://marc.vandersluys.nl
* Licence: [EUPL 1.2](https://www.eupl.eu/1.2/en/)


## References ##


<sub>Copyright (c) 2022-2023 Marc van der Sluys</sub>
